# root.generated.openapi-aclient
Root Signals JSON API provides a way to access Root Signals using provisioned API token

The `root.generated.openapi_aclient` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0 (latest)
- Package version: 1.0.0
- Generator version: 7.4.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3
* python-dateutil
* aiohttp
* pydantic

## Getting Started

In your own code, to use this library to connect and interact with root.generated.openapi-aclient,
you can run the following:

```python

import root.generated.openapi_aclient
from root.generated.openapi_aclient.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.app.rootsignals.ai
# See configuration.py for a list of all supported configuration parameters.
configuration = root.generated.openapi_aclient.Configuration(
    host = "https://api.app.rootsignals.ai"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: publicApiKey
configuration.api_key['publicApiKey'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['publicApiKey'] = 'Bearer'


# Enter a context with an instance of the API client
async with root.generated.openapi_aclient.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = root.generated.openapi_aclient.DatasetsApi(api_client)
    data_set_create_request = {"name":"My data set","url":"https://example.com"} # DataSetCreateRequest |  (optional)

    try:
        api_response = await api_instance.datasets_create(data_set_create_request=data_set_create_request)
        print("The response of DatasetsApi->datasets_create:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DatasetsApi->datasets_create: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.app.rootsignals.ai*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DatasetsApi* | [**datasets_create**](root/generated/openapi_aclient/docs/DatasetsApi.md#datasets_create) | **POST** /v1/datasets/ | 
*DatasetsApi* | [**datasets_destroy**](root/generated/openapi_aclient/docs/DatasetsApi.md#datasets_destroy) | **DELETE** /v1/datasets/{id}/ | 
*DatasetsApi* | [**datasets_list**](root/generated/openapi_aclient/docs/DatasetsApi.md#datasets_list) | **GET** /v1/datasets/ | 
*DatasetsApi* | [**datasets_retrieve**](root/generated/openapi_aclient/docs/DatasetsApi.md#datasets_retrieve) | **GET** /v1/datasets/{id}/ | 
*DatasetsApi* | [**datasets_status_update**](root/generated/openapi_aclient/docs/DatasetsApi.md#datasets_status_update) | **PUT** /v1/datasets/status/{id}/ | 
*EvaluatorsApi* | [**evaluators_calibrate_create**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_calibrate_create) | **POST** /v1/evaluators/calibrate/ | 
*EvaluatorsApi* | [**evaluators_calibrate_create2**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_calibrate_create2) | **POST** /v1/evaluators/calibrate/{id} | 
*EvaluatorsApi* | [**evaluators_create**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_create) | **POST** /v1/evaluators/ | 
*EvaluatorsApi* | [**evaluators_destroy**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_destroy) | **DELETE** /v1/evaluators/{id}/ | 
*EvaluatorsApi* | [**evaluators_duplicate_create**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_duplicate_create) | **POST** /v1/evaluators/duplicate/{id}/ | 
*EvaluatorsApi* | [**evaluators_execute_by_name_create**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_execute_by_name_create) | **POST** /v1/evaluators/execute/by-name/ | 
*EvaluatorsApi* | [**evaluators_execute_create**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_execute_create) | **POST** /v1/evaluators/execute/{id}/ | 
*EvaluatorsApi* | [**evaluators_list**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_list) | **GET** /v1/evaluators/ | 
*EvaluatorsApi* | [**evaluators_partial_update**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_partial_update) | **PATCH** /v1/evaluators/{id}/ | 
*EvaluatorsApi* | [**evaluators_retrieve**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_retrieve) | **GET** /v1/evaluators/{id}/ | 
*EvaluatorsApi* | [**evaluators_status_create**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_status_create) | **POST** /v1/evaluators/status/{id}/ | 
*EvaluatorsApi* | [**evaluators_status_update**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_status_update) | **PUT** /v1/evaluators/status/{id}/ | 
*EvaluatorsApi* | [**evaluators_update**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_update) | **PUT** /v1/evaluators/{id}/ | 
*EvaluatorsApi* | [**evaluators_versions_list**](root/generated/openapi_aclient/docs/EvaluatorsApi.md#evaluators_versions_list) | **GET** /v1/evaluators/versions/{id}/ | 
*ExecutionLogsApi* | [**execution_logs_list**](root/generated/openapi_aclient/docs/ExecutionLogsApi.md#execution_logs_list) | **GET** /v1/execution-logs/ | 
*ExecutionLogsApi* | [**execution_logs_retrieve**](root/generated/openapi_aclient/docs/ExecutionLogsApi.md#execution_logs_retrieve) | **GET** /v1/execution-logs/{log_id}/ | 
*JudgesApi* | [**judges_create**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_create) | **POST** /v1/judges/ | 
*JudgesApi* | [**judges_destroy**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_destroy) | **DELETE** /v1/judges/{id}/ | 
*JudgesApi* | [**judges_duplicate_create**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_duplicate_create) | **POST** /v1/judges/{id}/duplicate/ | 
*JudgesApi* | [**judges_execute_create**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_execute_create) | **POST** /v1/judges/{judge_id}/execute/ | 
*JudgesApi* | [**judges_generate_create**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_generate_create) | **POST** /v1/judges/generate/ | 
*JudgesApi* | [**judges_list**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_list) | **GET** /v1/judges/ | 
*JudgesApi* | [**judges_openai_chat_completions_create**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_openai_chat_completions_create) | **POST** /v1/judges/openai/chat/completions | 
*JudgesApi* | [**judges_openai_chat_completions_create2**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_openai_chat_completions_create2) | **POST** /v1/judges/{judge_id}/openai/chat/completions | 
*JudgesApi* | [**judges_partial_update**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_partial_update) | **PATCH** /v1/judges/{id}/ | 
*JudgesApi* | [**judges_refine_create**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_refine_create) | **POST** /v1/judges/{judge_id}/refine/ | 
*JudgesApi* | [**judges_refine_openai_chat_completions_create**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_refine_openai_chat_completions_create) | **POST** /v1/judges/{judge_id}/refine/openai/chat/completions | 
*JudgesApi* | [**judges_retrieve**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_retrieve) | **GET** /v1/judges/{id}/ | 
*JudgesApi* | [**judges_update**](root/generated/openapi_aclient/docs/JudgesApi.md#judges_update) | **PUT** /v1/judges/{id}/ | 
*ModelsApi* | [**models_create**](root/generated/openapi_aclient/docs/ModelsApi.md#models_create) | **POST** /v1/models/ | 
*ModelsApi* | [**models_destroy**](root/generated/openapi_aclient/docs/ModelsApi.md#models_destroy) | **DELETE** /v1/models/{id}/ | 
*ModelsApi* | [**models_list**](root/generated/openapi_aclient/docs/ModelsApi.md#models_list) | **GET** /v1/models/ | 
*ModelsApi* | [**models_partial_update**](root/generated/openapi_aclient/docs/ModelsApi.md#models_partial_update) | **PATCH** /v1/models/{id}/ | 
*ModelsApi* | [**models_retrieve**](root/generated/openapi_aclient/docs/ModelsApi.md#models_retrieve) | **GET** /v1/models/{id}/ | 
*ModelsApi* | [**models_update**](root/generated/openapi_aclient/docs/ModelsApi.md#models_update) | **PUT** /v1/models/{id}/ | 
*ObjectivesApi* | [**objectives_create**](root/generated/openapi_aclient/docs/ObjectivesApi.md#objectives_create) | **POST** /v1/objectives/ | 
*ObjectivesApi* | [**objectives_destroy**](root/generated/openapi_aclient/docs/ObjectivesApi.md#objectives_destroy) | **DELETE** /v1/objectives/{id}/ | 
*ObjectivesApi* | [**objectives_list**](root/generated/openapi_aclient/docs/ObjectivesApi.md#objectives_list) | **GET** /v1/objectives/ | 
*ObjectivesApi* | [**objectives_partial_update**](root/generated/openapi_aclient/docs/ObjectivesApi.md#objectives_partial_update) | **PATCH** /v1/objectives/{id}/ | 
*ObjectivesApi* | [**objectives_retrieve**](root/generated/openapi_aclient/docs/ObjectivesApi.md#objectives_retrieve) | **GET** /v1/objectives/{id}/ | 
*ObjectivesApi* | [**objectives_update**](root/generated/openapi_aclient/docs/ObjectivesApi.md#objectives_update) | **PUT** /v1/objectives/{id}/ | 
*ObjectivesApi* | [**objectives_versions_list**](root/generated/openapi_aclient/docs/ObjectivesApi.md#objectives_versions_list) | **GET** /v1/objectives/versions/{id}/ | 


## Documentation For Models

 - [DataSetCreate](root/generated/openapi_aclient/docs/DataSetCreate.md)
 - [DataSetCreateRequest](root/generated/openapi_aclient/docs/DataSetCreateRequest.md)
 - [DataSetList](root/generated/openapi_aclient/docs/DataSetList.md)
 - [DataSetType](root/generated/openapi_aclient/docs/DataSetType.md)
 - [DatasetRangeRequest](root/generated/openapi_aclient/docs/DatasetRangeRequest.md)
 - [Evaluator](root/generated/openapi_aclient/docs/Evaluator.md)
 - [EvaluatorCalibrationOutput](root/generated/openapi_aclient/docs/EvaluatorCalibrationOutput.md)
 - [EvaluatorCalibrationResult](root/generated/openapi_aclient/docs/EvaluatorCalibrationResult.md)
 - [EvaluatorDemonstrations](root/generated/openapi_aclient/docs/EvaluatorDemonstrations.md)
 - [EvaluatorDemonstrationsRequest](root/generated/openapi_aclient/docs/EvaluatorDemonstrationsRequest.md)
 - [EvaluatorExecutionFunctionParameterPropertyRequest](root/generated/openapi_aclient/docs/EvaluatorExecutionFunctionParameterPropertyRequest.md)
 - [EvaluatorExecutionFunctionParameterRequest](root/generated/openapi_aclient/docs/EvaluatorExecutionFunctionParameterRequest.md)
 - [EvaluatorExecutionFunctionParameterTypeEnum](root/generated/openapi_aclient/docs/EvaluatorExecutionFunctionParameterTypeEnum.md)
 - [EvaluatorExecutionFunctionRequest](root/generated/openapi_aclient/docs/EvaluatorExecutionFunctionRequest.md)
 - [EvaluatorExecutionFunctionsRequest](root/generated/openapi_aclient/docs/EvaluatorExecutionFunctionsRequest.md)
 - [EvaluatorExecutionFunctionsTypeEnum](root/generated/openapi_aclient/docs/EvaluatorExecutionFunctionsTypeEnum.md)
 - [EvaluatorExecutionRequest](root/generated/openapi_aclient/docs/EvaluatorExecutionRequest.md)
 - [EvaluatorExecutionResult](root/generated/openapi_aclient/docs/EvaluatorExecutionResult.md)
 - [EvaluatorInputsValue](root/generated/openapi_aclient/docs/EvaluatorInputsValue.md)
 - [EvaluatorInputsValueItems](root/generated/openapi_aclient/docs/EvaluatorInputsValueItems.md)
 - [EvaluatorListOutput](root/generated/openapi_aclient/docs/EvaluatorListOutput.md)
 - [EvaluatorReference](root/generated/openapi_aclient/docs/EvaluatorReference.md)
 - [EvaluatorReferenceRequest](root/generated/openapi_aclient/docs/EvaluatorReferenceRequest.md)
 - [EvaluatorRequest](root/generated/openapi_aclient/docs/EvaluatorRequest.md)
 - [EvaluatorResult](root/generated/openapi_aclient/docs/EvaluatorResult.md)
 - [ExecutionLogDetails](root/generated/openapi_aclient/docs/ExecutionLogDetails.md)
 - [ExecutionLogDetailsEvaluationContext](root/generated/openapi_aclient/docs/ExecutionLogDetailsEvaluationContext.md)
 - [ExecutionLogDetailsEvaluatorLatenciesInner](root/generated/openapi_aclient/docs/ExecutionLogDetailsEvaluatorLatenciesInner.md)
 - [ExecutionLogDetailsJudge](root/generated/openapi_aclient/docs/ExecutionLogDetailsJudge.md)
 - [ExecutionLogDetailsObjective](root/generated/openapi_aclient/docs/ExecutionLogDetailsObjective.md)
 - [ExecutionLogDetailsSkill](root/generated/openapi_aclient/docs/ExecutionLogDetailsSkill.md)
 - [ExecutionLogList](root/generated/openapi_aclient/docs/ExecutionLogList.md)
 - [ExecutionLogListEvaluationContext](root/generated/openapi_aclient/docs/ExecutionLogListEvaluationContext.md)
 - [ExecutionLogListSkill](root/generated/openapi_aclient/docs/ExecutionLogListSkill.md)
 - [GenerationModelParamsRequest](root/generated/openapi_aclient/docs/GenerationModelParamsRequest.md)
 - [ID](root/generated/openapi_aclient/docs/ID.md)
 - [InputVariable](root/generated/openapi_aclient/docs/InputVariable.md)
 - [InputVariableRequest](root/generated/openapi_aclient/docs/InputVariableRequest.md)
 - [Judge](root/generated/openapi_aclient/docs/Judge.md)
 - [JudgeExecutionRequest](root/generated/openapi_aclient/docs/JudgeExecutionRequest.md)
 - [JudgeExecutionResponse](root/generated/openapi_aclient/docs/JudgeExecutionResponse.md)
 - [JudgeFilesInner](root/generated/openapi_aclient/docs/JudgeFilesInner.md)
 - [JudgeGeneratorRequest](root/generated/openapi_aclient/docs/JudgeGeneratorRequest.md)
 - [JudgeGeneratorResponse](root/generated/openapi_aclient/docs/JudgeGeneratorResponse.md)
 - [JudgeList](root/generated/openapi_aclient/docs/JudgeList.md)
 - [JudgeRectifierRequestRequest](root/generated/openapi_aclient/docs/JudgeRectifierRequestRequest.md)
 - [JudgeRectifierResponse](root/generated/openapi_aclient/docs/JudgeRectifierResponse.md)
 - [JudgeRequest](root/generated/openapi_aclient/docs/JudgeRequest.md)
 - [JudgeStatusEnum](root/generated/openapi_aclient/docs/JudgeStatusEnum.md)
 - [Model](root/generated/openapi_aclient/docs/Model.md)
 - [ModelList](root/generated/openapi_aclient/docs/ModelList.md)
 - [ModelParams](root/generated/openapi_aclient/docs/ModelParams.md)
 - [ModelParamsRequest](root/generated/openapi_aclient/docs/ModelParamsRequest.md)
 - [ModelRequest](root/generated/openapi_aclient/docs/ModelRequest.md)
 - [NestedEvaluator](root/generated/openapi_aclient/docs/NestedEvaluator.md)
 - [NestedEvaluatorObjective](root/generated/openapi_aclient/docs/NestedEvaluatorObjective.md)
 - [NestedEvaluatorRequest](root/generated/openapi_aclient/docs/NestedEvaluatorRequest.md)
 - [NestedObjectiveEvaluator](root/generated/openapi_aclient/docs/NestedObjectiveEvaluator.md)
 - [NestedObjectiveEvaluatorRequest](root/generated/openapi_aclient/docs/NestedObjectiveEvaluatorRequest.md)
 - [NestedObjectiveList](root/generated/openapi_aclient/docs/NestedObjectiveList.md)
 - [NestedUserDetails](root/generated/openapi_aclient/docs/NestedUserDetails.md)
 - [NestedUserDetailsRequest](root/generated/openapi_aclient/docs/NestedUserDetailsRequest.md)
 - [NestedVectorObjective](root/generated/openapi_aclient/docs/NestedVectorObjective.md)
 - [NestedVectorObjectiveRequest](root/generated/openapi_aclient/docs/NestedVectorObjectiveRequest.md)
 - [Objective](root/generated/openapi_aclient/docs/Objective.md)
 - [ObjectiveList](root/generated/openapi_aclient/docs/ObjectiveList.md)
 - [ObjectiveRequest](root/generated/openapi_aclient/docs/ObjectiveRequest.md)
 - [ObjectiveValidator](root/generated/openapi_aclient/docs/ObjectiveValidator.md)
 - [ObjectiveValidatorRequest](root/generated/openapi_aclient/docs/ObjectiveValidatorRequest.md)
 - [PaginatedDataSetListList](root/generated/openapi_aclient/docs/PaginatedDataSetListList.md)
 - [PaginatedEvaluatorList](root/generated/openapi_aclient/docs/PaginatedEvaluatorList.md)
 - [PaginatedEvaluatorListOutputList](root/generated/openapi_aclient/docs/PaginatedEvaluatorListOutputList.md)
 - [PaginatedExecutionLogListList](root/generated/openapi_aclient/docs/PaginatedExecutionLogListList.md)
 - [PaginatedJudgeListList](root/generated/openapi_aclient/docs/PaginatedJudgeListList.md)
 - [PaginatedModelListList](root/generated/openapi_aclient/docs/PaginatedModelListList.md)
 - [PaginatedObjectiveList](root/generated/openapi_aclient/docs/PaginatedObjectiveList.md)
 - [PaginatedObjectiveListList](root/generated/openapi_aclient/docs/PaginatedObjectiveListList.md)
 - [PatchedEvaluatorRequest](root/generated/openapi_aclient/docs/PatchedEvaluatorRequest.md)
 - [PatchedJudgeRequest](root/generated/openapi_aclient/docs/PatchedJudgeRequest.md)
 - [PatchedModelRequest](root/generated/openapi_aclient/docs/PatchedModelRequest.md)
 - [PatchedObjectiveRequest](root/generated/openapi_aclient/docs/PatchedObjectiveRequest.md)
 - [Provider](root/generated/openapi_aclient/docs/Provider.md)
 - [ReferenceVariable](root/generated/openapi_aclient/docs/ReferenceVariable.md)
 - [ReferenceVariableRequest](root/generated/openapi_aclient/docs/ReferenceVariableRequest.md)
 - [SkillExecutionValidatorResult](root/generated/openapi_aclient/docs/SkillExecutionValidatorResult.md)
 - [SkillTestDataRequest](root/generated/openapi_aclient/docs/SkillTestDataRequest.md)
 - [SkillTestDataRequestDatasetRange](root/generated/openapi_aclient/docs/SkillTestDataRequestDatasetRange.md)
 - [SkillTestInputRequest](root/generated/openapi_aclient/docs/SkillTestInputRequest.md)
 - [SkillTypeEnum](root/generated/openapi_aclient/docs/SkillTypeEnum.md)
 - [StatusChange](root/generated/openapi_aclient/docs/StatusChange.md)
 - [StatusChangeRequest](root/generated/openapi_aclient/docs/StatusChangeRequest.md)
 - [StatusChangeStatusEnum](root/generated/openapi_aclient/docs/StatusChangeStatusEnum.md)
 - [StatusEnum](root/generated/openapi_aclient/docs/StatusEnum.md)
 - [ValidationResultStatus](root/generated/openapi_aclient/docs/ValidationResultStatus.md)
 - [VisibilityEnum](root/generated/openapi_aclient/docs/VisibilityEnum.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="publicApiKey"></a>
### publicApiKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author




